Installation
============

`csoundengine` needs a python version >= 3.8. For all platforms, the installation is 
the same::

    pip install csoundengine

    
Dependencies
------------

**csoundengine** depends on **csound** itself being installed. At the moment the minimal
version of csound supported is **6.16**. **csound 7**, even if not officially released
yet, is supported and tested regularly.

For **macos** and **windows**, **csound** can be installed by the provided installers
(`<https://github.com/csound/csound/releases>`_). For linux, the installation via
the distribution's package manager is the recommended way.
